@@ -54,11 +54,11 @@ required components such as an Max-aware 'old oracle style' join compiler
 (thetas with (+) outer indicators) are already done and available for
 integration- email the devel list if you're interested in working on
 this.
+
 """
+import datetime, itertools, re
 
-import datetime, itertools, re, warnings
-
-from sqlalchemy import exceptions, schema, sql, util
+from sqlalchemy import exc, schema, sql, util
 from sqlalchemy.sql import operators as sql_operators, expression as sql_expr
 from sqlalchemy.sql import compiler, visitors
 from sqlalchemy.engine import base as engine_base, default
@@ -169,17 +169,17 @@ class MaxSmallInteger(MaxInteger):
 class MaxNumeric(sqltypes.Numeric):
     """The FIXED (also NUMERIC, DECIMAL) data type."""
 
-    def __init__(self, precision=None, length=None, **kw):
+    def __init__(self, precision=None, scale=None, **kw):
         kw.setdefault('asdecimal', True)
-        super(MaxNumeric, self).__init__(length=length, precision=precision,
+        super(MaxNumeric, self).__init__(scale=scale, precision=precision,
                                          **kw)
 
     def bind_processor(self, dialect):
         return None
 
     def get_col_spec(self):
-        if self.length and self.precision:
-            return 'FIXED(%s, %s)' % (self.precision, self.length)
+        if self.scale and self.precision:
+            return 'FIXED(%s, %s)' % (self.precision, self.scale)
         elif self.precision:
             return 'FIXED(%s)' % self.precision
         else:
@@ -213,7 +213,7 @@ class MaxTimestamp(sqltypes.DateTime):
                 ms = getattr(value, 'microsecond', 0)
                 return value.strftime("%Y-%m-%d %H:%M:%S." + ("%06u" % ms))
             else:
-                raise exceptions.InvalidRequestError(
+                raise exc.InvalidRequestError(
                     "datetimeformat '%s' is not supported." % (
                     dialect.datetimeformat,))
         return process
@@ -235,7 +235,7 @@ class MaxTimestamp(sqltypes.DateTime):
                                 value[11:13], value[14:16], value[17:19],
                                 value[20:])])
             else:
-                raise exceptions.InvalidRequestError(
+                raise exc.InvalidRequestError(
                     "datetimeformat '%s' is not supported." % (
                     dialect.datetimeformat,))
         return process
@@ -256,7 +256,7 @@ class MaxDate(sqltypes.Date):
             elif dialect.datetimeformat == 'iso':
                 return value.strftime("%Y-%m-%d")
             else:
-                raise exceptions.InvalidRequestError(
+                raise exc.InvalidRequestError(
                     "datetimeformat '%s' is not supported." % (
                     dialect.datetimeformat,))
         return process
@@ -272,7 +272,7 @@ class MaxDate(sqltypes.Date):
                 return datetime.date(
                     *[int(v) for v in (value[0:4], value[5:7], value[8:10])])
             else:
-                raise exceptions.InvalidRequestError(
+                raise exc.InvalidRequestError(
                     "datetimeformat '%s' is not supported." % (
                     dialect.datetimeformat,))
         return process
@@ -293,7 +293,7 @@ class MaxTime(sqltypes.Time):
             elif dialect.datetimeformat == 'iso':
                 return value.strftime("%H-%M-%S")
             else:
-                raise exceptions.InvalidRequestError(
+                raise exc.InvalidRequestError(
                     "datetimeformat '%s' is not supported." % (
                     dialect.datetimeformat,))
         return process
@@ -310,7 +310,7 @@ class MaxTime(sqltypes.Time):
                 return datetime.time(
                     *[int(v) for v in (value[0:4], value[5:7], value[8:10])])
             else:
-                raise exceptions.InvalidRequestError(
+                raise exc.InvalidRequestError(
                     "datetimeformat '%s' is not supported." % (
                     dialect.datetimeformat,))
         return process
@@ -466,12 +466,13 @@ class MaxDBResultProxy(engine_base.ResultProxy):
 
 
 class MaxDBDialect(default.DefaultDialect):
+    name = 'maxdb'
     supports_alter = True
     supports_unicode_statements = True
     max_identifier_length = 32
     supports_sane_rowcount = True
     supports_sane_multi_rowcount = False
-    preexecute_sequences = True
+    preexecute_pk_sequences = True
 
     # MaxDB-specific
     datetimeformat = 'internal'
@@ -513,9 +514,6 @@ class MaxDBDialect(default.DefaultDialect):
         else:
             return sqltypes.adapt_type(typeobj, colspecs)
 
-    def create_execution_context(self, connection, **kw):
-        return MaxDBExecutionContext(self, connection, **kw)
-
     def do_execute(self, cursor, statement, parameters, context=None):
         res = cursor.execute(statement, parameters)
         if isinstance(res, int) and context is not None:
@@ -599,9 +597,9 @@ class MaxDBDialect(default.DefaultDialect):
 
         rows = connection.execute(st, params).fetchall()
         if not rows:
-            raise exceptions.NoSuchTableError(table.fullname)
+            raise exc.NoSuchTableError(table.fullname)
 
-        include_columns = util.Set(include_columns or [])
+        include_columns = set(include_columns or [])
 
         for row in rows:
             (name, mode, col_type, encoding, length, scale,
@@ -632,9 +630,8 @@ class MaxDBDialect(default.DefaultDialect):
                 type_cls = ischema_names[col_type.lower()]
                 type_instance = type_cls(*type_args, **type_kw)
             except KeyError:
-                warnings.warn(RuntimeWarning(
-                    "Did not recognize type '%s' of column '%s'" %
-                    (col_type, name)))
+                util.warn("Did not recognize type '%s' of column '%s'" %
+                          (col_type, name))
                 type_instance = sqltypes.NullType
 
             col_kw = {'autoincrement': False}
@@ -649,14 +646,14 @@ class MaxDBDialect(default.DefaultDialect):
                         col_kw['autoincrement'] = True
                     else:
                         # strip current numbering
-                        col_kw['default'] = schema.PassiveDefault(
+                        col_kw['server_default'] = schema.DefaultClause(
                             sql.text('SERIAL'))
                         col_kw['autoincrement'] = True
                 else:
-                    col_kw['default'] = schema.PassiveDefault(
+                    col_kw['server_default'] = schema.DefaultClause(
                         sql.text(func_def))
             elif constant_def is not None:
-                col_kw['default'] = schema.PassiveDefault(sql.text(
+                col_kw['server_default'] = schema.DefaultClause(sql.text(
                     "'%s'" % constant_def.replace("'", "''")))
 
             table.append_column(schema.Column(name, type_instance, **col_kw))
@@ -666,7 +663,7 @@ class MaxDBDialect(default.DefaultDialect):
         for fkeyname, fkey in fk_sets:
             fkey = list(fkey)
             if include_columns:
-                key_cols = util.Set([r.COLUMNNAME for r in fkey])
+                key_cols = set([r.COLUMNNAME for r in fkey])
                 if key_cols != include_columns:
                     continue
 
@@ -704,7 +701,7 @@ class MaxDBDialect(default.DefaultDialect):
                              autoload=True, autoload_with=connection,
                              **table_kw)
 
-            constraint = schema.ForeignKeyConstraint(columns, referants,
+            constraint = schema.ForeignKeyConstraint(columns, referants, link_to_name=True,
                                                      **constraint_kw)
             table.append_constraint(constraint)
 
@@ -732,7 +729,7 @@ class MaxDBCompiler(compiler.DefaultCompiler):
 
     # These functions must be written without parens when called with no
     # parameters.  e.g. 'SELECT DATE FROM DUAL' not 'SELECT DATE() FROM DUAL'
-    bare_functions = util.Set([
+    bare_functions = set([
         'CURRENT_SCHEMA', 'DATE', 'FALSE', 'SYSDBA', 'TIME', 'TIMESTAMP',
         'TIMEZONE', 'TRANSACTION', 'TRUE', 'USER', 'UID', 'USERGROUP',
         'UTCDATE', 'UTCDIFF'])
@@ -829,12 +826,12 @@ class MaxDBCompiler(compiler.DefaultCompiler):
 
         # No ORDER BY in subqueries.
         if order_by:
-            if self.is_subquery(select):
+            if self.is_subquery():
                 # It's safe to simply drop the ORDER BY if there is no
                 # LIMIT.  Right?  Other dialects seem to get away with
                 # dropping order.
                 if select._limit:
-                    raise exceptions.InvalidRequestError(
+                    raise exc.InvalidRequestError(
                         "MaxDB does not support ORDER BY in subqueries")
                 else:
                     return ""
@@ -845,9 +842,9 @@ class MaxDBCompiler(compiler.DefaultCompiler):
     def get_select_precolumns(self, select):
         # Convert a subquery's LIMIT to TOP
         sql = select._distinct and 'DISTINCT ' or ''
-        if self.is_subquery(select) and select._limit:
+        if self.is_subquery() and select._limit:
             if select._offset:
-                raise exceptions.InvalidRequestError(
+                raise exc.InvalidRequestError(
                     'MaxDB does not support LIMIT with an offset.')
             sql += 'TOP %s ' % select._limit
         return sql
@@ -855,11 +852,11 @@ class MaxDBCompiler(compiler.DefaultCompiler):
     def limit_clause(self, select):
         # The docs say offsets are supported with LIMIT.  But they're not.
         # TODO: maybe emulate by adding a ROWNO/ROWNUM predicate?
-        if self.is_subquery(select):
+        if self.is_subquery():
             # sub queries need TOP
             return ''
         elif select._offset:
-            raise exceptions.InvalidRequestError(
+            raise exc.InvalidRequestError(
                 'MaxDB does not support LIMIT with an offset.')
         else:
             return ' \n LIMIT %s' % (select._limit,)
@@ -870,7 +867,7 @@ class MaxDBCompiler(compiler.DefaultCompiler):
 
         colparams = self._get_colparams(insert)
         for value in (insert.parameters or {}).itervalues():
-            if isinstance(value, sql_expr._Function):
+            if isinstance(value, sql_expr.Function):
                 self._safeserial = False
                 break
 
@@ -893,7 +890,7 @@ class MaxDBDefaultRunner(engine_base.DefaultRunner):
 
 
 class MaxDBIdentifierPreparer(compiler.IdentifierPreparer):
-    reserved_words = util.Set([
+    reserved_words = set([
         'abs', 'absolute', 'acos', 'adddate', 'addtime', 'all', 'alpha',
         'alter', 'any', 'ascii', 'asin', 'atan', 'atan2', 'avg', 'binary',
         'bit', 'boolean', 'byte', 'case', 'ceil', 'ceiling', 'char',
@@ -973,7 +970,7 @@ class MaxDBSchemaGenerator(compiler.SchemaGenerator):
         # Assign DEFAULT SERIAL heuristically
         elif column.primary_key and column.autoincrement:
             # For SERIAL on a non-primary key member, use
-            # PassiveDefault(text('SERIAL'))
+            # DefaultClause(text('SERIAL'))
             try:
                 first = [c for c in column.table.primary_key.columns
                          if (c.autoincrement and
@@ -988,7 +985,7 @@ class MaxDBSchemaGenerator(compiler.SchemaGenerator):
         return ' '.join(colspec)
 
     def get_column_default_string(self, column):
-        if isinstance(column.default, schema.PassiveDefault):
+        if isinstance(column.server_default, schema.DefaultClause):
             if isinstance(column.default.arg, basestring):
                 if isinstance(column.type, sqltypes.Integer):
                     return str(column.default.arg)
@@ -1088,23 +1085,15 @@ def _autoserial_column(table):
                 if col.default.optional:
                     return index, col
             elif (col.default is None or
-                  (not isinstance(col.default, schema.PassiveDefault))):
+                  (not isinstance(col.server_default, schema.DefaultClause))):
                 return index, col
 
     return None, None
 
-def descriptor():
-    return {'name': 'maxdb',
-    'description': 'MaxDB',
-    'arguments': [
-        ('user', "Database Username", None),
-        ('password', "Database Password", None),
-        ('database', "Database Name", None),
-        ('host', "Hostname", None)]}
-
 dialect = MaxDBDialect
 dialect.preparer = MaxDBIdentifierPreparer
 dialect.statement_compiler = MaxDBCompiler
 dialect.schemagenerator = MaxDBSchemaGenerator
 dialect.schemadropper = MaxDBSchemaDropper
 dialect.defaultrunner = MaxDBDefaultRunner
+dialect.execution_ctx_cls = MaxDBExecutionContext
\ No newline at end of file
